# ApexLab Initial Release Scope

This document tracks the practical release assembly surface for Leg 1.

Current release target version: `1.0.0`.

The authoritative source of explicit package constraints remains:

- `APEXLAB_TOOLKIT_AUTHORITATIVE_SCHEMATIC.md`

Current Leg 1 focus:

- constrained core model family
- diagnostics
- evaluation/report helpers
- deterministic split utilities
- demos/examples
- packaging/tests
